@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::JSONP;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub register {
   my ($self, $app, $conf) = @_;
@@ -20,7 +20,7 @@ sub register {
       return $callback
         ?   $self->render(text => $callback . '('
           . $self->render(json => $ref, partial => 1) . ')')
-        : $self->render_json($ref);
+        : $self->render(json => $ref);
     }
   );
 }
